==> mastapy-14.0.0.tar.gz: mastapy-14.0.0/mastapy/_private/utility/units_and_measurements/measurements/_1784.py <==
"""Viscosity"""

from __future__ import annotations

from typing import ClassVar, TYPE_CHECKING

from mastapy._private._internal import utility
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.utility.units_and_measurements import _1655

_VISCOSITY = python_net_import(
    "SMT.MastaAPI.Utility.UnitsAndMeasurements.Measurements", "Viscosity"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="Viscosity")
    CastSelf = TypeVar("CastSelf", bound="Viscosity._Cast_Viscosity")


__docformat__ = "restructuredtext en"
__all__ = ("Viscosity",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_Viscosity:
    """Special nested class for casting Viscosity to subclasses."""

    __parent__: "Viscosity"

    @property
    def measurement_base(self: "CastSelf") -> "_1655.MeasurementBase":
        return self.__parent__._cast(_1655.MeasurementBase)

    @property
    def viscosity(self: "CastSelf") -> "Viscosity":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class Viscosity(_1655.MeasurementBase):
    """Viscosity

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _VISCOSITY

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_Viscosity":
        """Cast to another type.

        Returns:
            _Cast_Viscosity
        """
        return _Cast_Viscosity(self)

==> mastapy-14.1.0b2.tar.gz: mastapy-14.1.0b2/mastapy/_private/utility/units_and_measurements/measurements/_1784.py <==
"""Time"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal import utility
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.utility.units_and_measurements import _1666

_TIME = python_net_import(
    "SMT.MastaAPI.Utility.UnitsAndMeasurements.Measurements", "Time"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="Time")
    CastSelf = TypeVar("CastSelf", bound="Time._Cast_Time")


__docformat__ = "restructuredtext en"
__all__ = ("Time",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_Time:
    """Special nested class for casting Time to subclasses."""

    __parent__: "Time"

    @property
    def measurement_base(self: "CastSelf") -> "_1666.MeasurementBase":
        return self.__parent__._cast(_1666.MeasurementBase)

    @property
    def time(self: "CastSelf") -> "Time":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class Time(_1666.MeasurementBase):
    """Time

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _TIME

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_Time":
        """Cast to another type.

        Returns:
            _Cast_Time
        """
        return _Cast_Time(self)
